Index: chrome/browser/gtk/download_item_gtk.cc |
=================================================================== |
--- chrome/browser/gtk/download_item_gtk.cc (revision 16106) |
+++ chrome/browser/gtk/download_item_gtk.cc (working copy) |
@@ -165,12 +165,12 @@ |
name_label_ = gtk_label_new(NULL); |
// TODO(estade): This is at best an educated guess, since we don't actually |
// use ChromeFont() to draw the text. This is why we need to add so |
// much padding when we set the size request. We need to either use ChromeFont |
// or somehow extend TextElider. |
std::wstring elided_filename = gfx::ElideFilename( |
download_model_->download()->GetFileName(), |
- ChromeFont(), kTextWidth); |
+ gfx::Font(), kTextWidth); |
gchar* label_markup = |
g_markup_printf_escaped(kLabelColorMarkup, kFilenameColor, |
WideToUTF8(elided_filename).c_str()); |
@@ -165,12 +165,12 @@ |
name_label_ = gtk_label_new(NULL); |
// TODO(estade): This is at best an educated guess, since we don't actually |
- // use ChromeFont() to draw the text. This is why we need to add so |
- // much padding when we set the size request. We need to either use ChromeFont |
+ // use gfx::Font() to draw the text. This is why we need to add so |
+ // much padding when we set the size request. We need to either use gfx::Font |
// or somehow extend TextElider. |
std::wstring elided_filename = gfx::ElideFilename( |